#!/bin/sh
#/****************************************************************************/
#/* SYSLOG CONF SETUP SCRIPT                                                 */
#/*                                          Copyright FUJITSU LTD 2004-2008 */
#/*                                                                          */
#/* $Name: SLINPSA-2_11_0-0 $                                                     */
#/****************************************************************************/
# Development date : Tue NOV 18 2008
# For RHEL6 Changed from syslog.conf into rsyslog.conf Mon Aug 30 2010 F.Nakamura

#==============================================================================
# This is the script to add or remove the syslog.conf setting for PSA.
# Only FJSVpsa Installer is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================


#Syslog Reconfiguration Function
syslog_HUP()
{
    pssyslog=`ps aux|egrep "syslogd"|grep -v "grep"`
    syslogal=`ps aux|egrep "syslogd"|grep -v "grep"|wc -l`

    if [ $syslogal -ne 0 ]
	then
	set `echo "$pssyslog"`

	kill -HUP $2
    fi
}
    

#Syslog Configuration Function

# --2010.8.30 For RHEL6 (Changed from syslog.conf into rsyslog.conf) --
if [ -e /etc/rsyslog.conf ]
    then
    SLCONF="/etc/rsyslog.conf"
else
    SLCONF="/etc/syslog.conf"
fi
# ---------------------------------------------------------------------

#Pipe for LOGGETD
BASEDIR="/"
FIFO="var/opt/FJSVpsa/path/syslog_fifo"
STR=$BASEDIR$FIFO

FULLFIFO=$STR

STARTLINE="## Setup for FJSVpsa Please Do not remove the next line##"
STOPLINE="## End of Setup for FJSVpsa ##"


#Temporary File
TEMP=/tmp/FJSVsyslog.conf

#Authentication
WHO=`whoami|egrep "^root$"|wc -l`
if [ $WHO -ne 1 ]
    then

    echo "slsetup.sh : Opetation not permitted. root only"
    exit 1
fi

#Check the PSA Settings
if [ -w $SLCONF ]
    then
    
    #Count the settings for PSA.
    line=`egrep "\|$STR" $SLCONF | wc -l`
    #Count the settings for PSA which start with comment code.
    cout=`egrep "\|$STR" $SLCONF|egrep "^[ 	]*#"|wc -l`

    #Count the linefeed code
    ncnt=`cat $SLCONF|wc -l`
    #Count the total line of $SLCONF
    zcnt=`grep $ $SLCONF|wc -l`
    
    #Discriminate the operation install or uninstall by 1st argument
    case $1 in
	'install')
	    #INSTALL
	    
	    if [ $line -eq 0 -o $line -eq $cout ]
		then
		#There is no setting for PSA.
		#There are some settings for PSA,
		# but all ones start with comment code.

		if [ $ncnt -ne $zcnt ]
		    then
		    #In this situation, 
		    # the last line of this file doesn't include linefeed code.
		    #Add the linefeed code
		    echo >> $SLCONF
		fi

		#Add the new setting.
		echo $STARTLINE >> $SLCONF
		echo "*.info;mail.none;news.none;authpriv.none;cron.none |$STR" \
		    >> $SLCONF
		echo $STOPLINE >> $SLCONF

		#Create the new FIFO File ,and restart the syslog service
		if [ ! -e $STR ]
		    then
		    mkfifo -m 600 $STR
		fi
		syslog_HUP
		
	    fi

	    exit 0;;
		#There are some settings for PSA,
		# one or more settings start with comment code.
		#In this situation, this script doesn't add the new setting. 

	'uninstall')
	    #UNINSTALL
	    startl=`grep -n "$STARTLINE" $SLCONF|cut -d: -f1`
	    stopl=`grep -n "$STOPLINE" $SLCONF|cut -d: -f1`
	    
	    if [ -z $startl ]
                then
		#Cannot find the start mark of PSA's setting
		exit 0
	    fi
	    
	    if [ -z $stopl ]
                then
		#Cannot find the end mark of PSA's setting
		exit 0
	    fi
	    
	    if [ `expr $stopl - $startl` -eq 2 ]
                then
		head -n `expr $startl - 1` $SLCONF > $TEMP
		tail -n `expr $zcnt - $stopl` $SLCONF >> $TEMP
		chmod --reference $SLCONF $TEMP
		mv $TEMP $SLCONF
	    fi
	    
	    #Derete the FIFO File, and restart the syslog service
	    rm -f $STR
            # Restore SELinux policy for RHEL6
            if [ -e /etc/rsyslog.conf ]
		then
		restorecon -F $SLCONF
            fi
	    syslog_HUP
	    exit 0;;
	
	*)
	    echo "slsetup.sh: Invalid option '$1'"
	    echo "Usage:  slsetup.sh {install|uninstall}"
	    exit 1;;
    esac
    
else
    echo "Can't change the file: '$SLCONF'"
    exit 1
   
fi
